@@ -1,7 +1,7 @@
 package Bencher::Scenario::BigInt;
 
 our $DATE = '2017-01-25'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -47,7 +47,7 @@ Bencher::Scenario::BigInt - Benchmark arbitrary size integer arithmetics
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::BigInt (from Perl distribution Bencher-Scenario-BigInt), released on 2017-01-25.
+This document describes version 0.03 of Bencher::Scenario::BigInt (from Perl distribution Bencher-Scenario-BigInt), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -123,11 +123,11 @@ Benchmark with default options (C<< bencher -m BigInt >>):
  +-----------------+---------+-----------+-----------+------------+---------+---------+
  | participant     | dataset | rate (/s) | time (ms) | vs_slowest |  errors | samples |
  +-----------------+---------+-----------+-----------+------------+---------+---------+
- | 1k-Math::BigInt | 1e100   |      14.5 |   69.2    |        1   | 5.4e-05 |      20 |
- | 1k-Math::BigInt | 1e1     |      28   |   36      |        1.9 | 8.1e-05 |      20 |
- | 1k-Math::GMP    | 1e100   |     110   |    9      |        7.6 | 9.4e-06 |      20 |
- | 1k-Math::GMP    | 1e1     |     161   |    6.2    |       11.2 | 5.8e-06 |      20 |
- | 1k-native       | 1e1     |   29000   |    0.0345 |     2000   | 1.3e-08 |      20 |
+ | 1k-Math::BigInt | 1e100   |      14.3 |  70.2     |        1   |   4e-05 |      20 |
+ | 1k-Math::BigInt | 1e1     |      26   |  38       |        1.8 | 5.3e-05 |      20 |
+ | 1k-Math::GMP    | 1e100   |     110   |   9       |        7.8 | 1.2e-05 |      20 |
+ | 1k-Math::GMP    | 1e1     |     160   |   6.2     |       11   | 7.8e-06 |      20 |
+ | 1k-native       | 1e1     |   28827   |   0.03469 |     2022.3 | 4.6e-11 |      20 |
  +-----------------+---------+-----------+-----------+------------+---------+---------+
 
 
@@ -137,9 +137,9 @@ Benchmark module startup overhead (C<< bencher -m BigInt --module-startup >>):
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Math::BigInt        | 1.8                          | 5.3                | 21             |      33   |                   27.7 |        1   | 8.7e-05 |      20 |
- | Math::GMP           | 0.83                         | 4.1                | 16             |      15   |                    9.7 |        2.1 | 5.8e-05 |      20 |
- | perl -e1 (baseline) | 3.7                          | 7                  | 19             |       5.3 |                    0   |        6.1 | 1.7e-05 |      20 |
+ | Math::BigInt        | 1.8                          | 5.2                | 21             |      33   |                   27.3 |        1   | 6.7e-05 |      20 |
+ | Math::GMP           | 0.82                         | 4.1                | 16             |      15   |                    9.3 |        2.2 | 1.7e-05 |      21 |
+ | perl -e1 (baseline) | 3.7                          | 7                  | 19             |       5.7 |                    0   |        5.7 | 1.4e-05 |      20 |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
