@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::BigInt;
 
-our $VERSION = 0.02; # VERSION
+our $VERSION = 0.03; # VERSION
 
 our $results = [
   [
@@ -9,48 +9,48 @@ our $results = [
     [
       {
         dataset     => "1e100",
-        errors      => 5.4e-05,
+        errors      => 4e-05,
         participant => "1k-Math::BigInt",
-        rate        => 14.5,
+        rate        => 14.3,
         samples     => 20,
-        time        => 69.2,
+        time        => 70.2,
         vs_slowest  => 1,
       },
       {
         dataset     => "1e1",
-        errors      => 8.1e-05,
+        errors      => 5.3e-05,
         participant => "1k-Math::BigInt",
-        rate        => 28,
+        rate        => 26,
         samples     => 20,
-        time        => 36,
-        vs_slowest  => 1.9,
+        time        => 38,
+        vs_slowest  => 1.8,
       },
       {
         dataset     => "1e100",
-        errors      => 9.4e-06,
+        errors      => 1.2e-05,
         participant => "1k-Math::GMP",
         rate        => 110,
         samples     => 20,
         time        => 9,
-        vs_slowest  => 7.6,
+        vs_slowest  => 7.8,
       },
       {
         dataset     => "1e1",
-        errors      => 5.8e-06,
+        errors      => 7.8e-06,
         participant => "1k-Math::GMP",
-        rate        => 161,
+        rate        => 160,
         samples     => 20,
         time        => 6.2,
-        vs_slowest  => 11.2,
+        vs_slowest  => 11,
       },
       {
         dataset     => "1e1",
-        errors      => 1.3e-08,
+        errors      => 4.6e-11,
         participant => "1k-native",
-        rate        => 29000,
+        rate        => 28827,
         samples     => 20,
-        time        => 0.0345,
-        vs_slowest  => 2000,
+        time        => 0.03469,
+        vs_slowest  => 2022.3,
       },
     ],
     {
@@ -173,7 +173,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => "2615.210",
+                                              speed                        => 2885.039,
                                               stepping                     => 4,
                                             },
                                             {
@@ -288,7 +288,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2636.648,
+                                              speed                        => 2848.234,
                                               stepping                     => 4,
                                             },
                                             {
@@ -403,7 +403,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => "2828.820",
+                                              speed                        => 2847.906,
                                               stepping                     => 4,
                                             },
                                             {
@@ -518,13 +518,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => "2859.500",
+                                              speed                        => 2896.468,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 3.29615306854248,
+      "func.elapsed_time"              => 3.50724411010742,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__" => 1.034,
                                             "Bencher::Scenario::BigInt" => undef,
                                             "Benchmark::Dumb" => "0.10",
                                             "Devel::Platform::Info" => 0.16,
@@ -564,9 +565,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1485315081,
       "func.scenario_module_sha1sum"   => "436a0023b9b50f8b7933a33257addffb5946d196",
       "func.scenario_module_sha256sum" => "8d67d2b5fee61b3ef1626f57f4ab3502dbf566a42767a0a9c0da80bec50f2666",
-      "func.time_end"                  => 1485315197.98134,
+      "func.time_end"                  => 1485317370.99103,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1485315194.68518,
+      "func.time_start"                => 1485317367.48379,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
